django-kindling
===============

To assist set-up of nice Django projects.

Quickstart
----------

To get started::

    % mkvirtualenv yourproject
    (yourproject) % pip install django-kindling
    (yourproject) % kindling yourproject
    (yourproject) % workon yourproject
    (yourproject) % pip install -r yourproject/requirements.txt


Todos
-----

 * Create boilerplate HTML
 * Create boilerplate CSS
